==> ts-pfsense_1.04-01.tar.gz: ts-pfsense/ts_state.php <==
<?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

/*
        pfSense_MODULE: aliases
*/

require("guiconfig.inc");
require_once("functions.inc");
require_once("filter.inc");
require_once("shaper.inc");

if (!is_array($config['aliases']['alias']))
        $config['aliases']['alias'] = array();
$a_aliases = &$config['aliases']['alias'];

if ($_POST) {

        $pconfig = $_POST;

        if ($_POST['apply']) {
                $retval = 0;

                /* reload all components that use aliases */
                $retval = filter_configure();

                if(stristr($retval, "error") <> true)
                    $savemsg = get_std_save_message($retval);
                else
                    $savemsg = $retval;
                if ($retval == 0)
                        clear_subsystem_dirty('aliases');
        }
}

if ($_GET['act'] == "del") {
        if ($a_aliases[$_GET['id']]) {
                /* make sure rule is not being referenced by any nat or filter rules */
                $is_alias_referenced = false;
                $referenced_by = false;
                $alias_name = $a_aliases[$_GET['id']]['name'];
                // Firewall rules
                find_alias_reference(array('filter', 'rule'), array('source', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('filter', 'rule'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('filter', 'rule'), array('source', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('filter', 'rule'), array('destination', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                // NAT Rules
                find_alias_reference(array('nat', 'rule'), array('source', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('source', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('destination', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('target'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('local-port'), $alias_name, $is_alias_referenced, $referenced_by);
                // NAT 1:1 Rules
                find_alias_reference(array('nat', 'onetoone'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                // NAT Outbound Rules
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('source', 'network'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('sourceport'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('dstport'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('target'), $alias_name, $is_alias_referenced, $referenced_by);
                // Alias in an alias
                find_alias_reference(array('aliases', 'alias'), array('address'), $alias_name, $is_alias_referenced, $referenced_by);
                if($is_alias_referenced == true) {
                        $savemsg = sprintf(gettext("Cannot delete alias. Currently in use by %s"), $referenced_by);
                } else {
                        unset($a_aliases[$_GET['id']]);
                        write_config();
                        filter_configure();
                        mark_subsystem_dirty('aliases');
                        header("Location: firewall_aliases.php");
                        exit;
                }
        }
}

function find_alias_reference($section, $field, $origname, &$is_alias_referenced, &$referenced_by) {
        global $config;
        if(!$origname || $is_alias_referenced)
                return;

        $sectionref = &$config;
        foreach($section as $sectionname) {
                if(is_array($sectionref) && isset($sectionref[$sectionname]))
                        $sectionref = &$sectionref[$sectionname];
                else
                        return;
        }

        if(is_array($sectionref)) {
                foreach($sectionref as $itemkey => $item) {
                        $fieldfound = true;
                        $fieldref = &$sectionref[$itemkey];
                        foreach($field as $fieldname) {
                                if(is_array($fieldref) && isset($fieldref[$fieldname]))
                                        $fieldref = &$fieldref[$fieldname];
                                else {
                                        $fieldfound = false;
                                        break;
                                }
                        }
                        if($fieldfound && $fieldref == $origname) {
                                $is_alias_referenced = true;
                                if(is_array($item))
                                        $referenced_by = $item['descr'];
                                break;
                        }
                }
        }
}

$pgtitle = array(gettext("ThreatSTOP"),gettext("Installation"));
include("head.inc");

?>

<body link="#0000CC" vlink="#0000CC" alink="#0000CC">
<?php
/*
 * GS-905
 */
require("threatstop.conf.php");
if ( ( $PF_VERSION_MAJOR == 2 && $PF_VERSION_MINOR <= 2 ) || ( $PF_VERSION_MAJOR == 1 ) ) {

        include("fbegin.inc"); 
}
?>
<?php
global $config;
$ts_enabled = false;

foreach ($config['filter']['rule'] as $some_rule) {

    if (strpos(strtolower($some_rule['descr']), 'threatstop') !== false) {
        $ts_enabled = true;
    }

}

$uninstall_button = '';

if ($ts_enabled) {

    $ts_title = 'ThreatSTOP enabled';
        $ts_script = 'tsdisable.php';
        $ts_button_text = 'Disable';
        $ts_label = 'Disable ThreatSTOP';

} else {

    $ts_title = 'ThreatSTOP disabled';
        $ts_script = 'tsenable.php';
    $ts_button_text = 'Enable';
    $ts_label = 'Enable ThreatSTOP';
    $uninstall_button = '
<tr style="height: 90px;"><td><span style="float:right;">Completely remove ThreatSTOP</span></td><td>
<form style="float:left;" action="tsremove.php">
    <input type="submit" value="Remove" />
</form>
</td>
</tr>
';

}


$ts_errors = '';
if(file_exists("{$g['varrun_path']}/filter_reload_status"))
        $ts_errors = file_get_contents("{$g['varrun_path']}/filter_reload_status");

?>
<h1><?=$ts_title ?></h1>

<div>
<table style="padding: 60px 150px; font-size: 140%;">
<tr><td><span style="float:right;"><?=$ts_label?></span></td><td>
<form style="float:left;" action="<?=$ts_script ?>">
    <input type="submit" value="<?=$ts_button_text ?>" />
</form>
</td></tr>
<?php echo $uninstall_button; ?>
</table>
</div>

<?php if ($ts_errors) {?>
<br />
<br />
<div id="status" name="status" style="padding:5px; border:1px dashed #990000; background-color: #ffffff; color: #000000;">
        <?php echo $ts_errors; ?>
</div>
<br />
<table border="0" cellpadding="5" cellspacing="0" width="75%">
  <tbody>
    <tr>
    <td colspan="2">
    <h4><a target="threatstop" href="http://www.threatstop.com/">Click Here to Login to Your ThreatSTOP account</a></h4>
    </td>
    </tr>
  </tbody>
</table>
</form><?php } ?>
<?php include("fend.inc"); ?>
</body>
</html>

==> ts-pfsense_1.05-02.tar.gz: ts-pfsense/ts_state.php <==
<?php
/**
 *
 * Copyright(c) 2006-2018 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

/*
        pfSense_MODULE: aliases
*/

require("guiconfig.inc");
require_once("functions.inc");
require_once("filter.inc");
require_once("shaper.inc");

if (!is_array($config['aliases']['alias']))
        $config['aliases']['alias'] = array();
$a_aliases = &$config['aliases']['alias'];

if ($_POST) {

        $pconfig = $_POST;

        if ($_POST['apply']) {
                $retval = 0;

                /* reload all components that use aliases */
                $retval = filter_configure();

                if(stristr($retval, "error") <> true)
                    $savemsg = get_std_save_message($retval);
                else
                    $savemsg = $retval;
                if ($retval == 0)
                        clear_subsystem_dirty('aliases');
        }
}

if ($_GET['act'] == "del") {
        if ($a_aliases[$_GET['id']]) {
                /* make sure rule is not being referenced by any nat or filter rules */
                $is_alias_referenced = false;
                $referenced_by = false;
                $alias_name = $a_aliases[$_GET['id']]['name'];
                // Firewall rules
                find_alias_reference(array('filter', 'rule'), array('source', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('filter', 'rule'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('filter', 'rule'), array('source', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('filter', 'rule'), array('destination', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                // NAT Rules
                find_alias_reference(array('nat', 'rule'), array('source', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('source', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('destination', 'port'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('target'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'rule'), array('local-port'), $alias_name, $is_alias_referenced, $referenced_by);
                // NAT 1:1 Rules
                find_alias_reference(array('nat', 'onetoone'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                // NAT Outbound Rules
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('source', 'network'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('sourceport'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('destination', 'address'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('dstport'), $alias_name, $is_alias_referenced, $referenced_by);
                find_alias_reference(array('nat', 'advancedoutbound', 'rule'), array('target'), $alias_name, $is_alias_referenced, $referenced_by);
                // Alias in an alias
                find_alias_reference(array('aliases', 'alias'), array('address'), $alias_name, $is_alias_referenced, $referenced_by);
                if($is_alias_referenced == true) {
                        $savemsg = sprintf(gettext("Cannot delete alias. Currently in use by %s"), $referenced_by);
                } else {
                        unset($a_aliases[$_GET['id']]);
                        write_config();
                        filter_configure();
                        mark_subsystem_dirty('aliases');
                        header("Location: firewall_aliases.php");
                        exit;
                }
        }
}

function find_alias_reference($section, $field, $origname, &$is_alias_referenced, &$referenced_by) {
        global $config;
        if(!$origname || $is_alias_referenced)
                return;

        $sectionref = &$config;
        foreach($section as $sectionname) {
                if(is_array($sectionref) && isset($sectionref[$sectionname]))
                        $sectionref = &$sectionref[$sectionname];
                else
                        return;
        }

        if(is_array($sectionref)) {
                foreach($sectionref as $itemkey => $item) {
                        $fieldfound = true;
                        $fieldref = &$sectionref[$itemkey];
                        foreach($field as $fieldname) {
                                if(is_array($fieldref) && isset($fieldref[$fieldname]))
                                        $fieldref = &$fieldref[$fieldname];
                                else {
                                        $fieldfound = false;
                                        break;
                                }
                        }
                        if($fieldfound && $fieldref == $origname) {
                                $is_alias_referenced = true;
                                if(is_array($item))
                                        $referenced_by = $item['descr'];
                                break;
                        }
                }
        }
}

$pgtitle = array(gettext("ThreatSTOP"),gettext("Installation"));
include("head.inc");

?>

<body link="#0000CC" vlink="#0000CC" alink="#0000CC">
<?php
/*
 * GS-905
 */
require("threatstop.conf.php");
if ( ( $PF_VERSION_MAJOR == 2 && $PF_VERSION_MINOR <= 2 ) || ( $PF_VERSION_MAJOR == 1 ) ) {

        include("fbegin.inc"); 
}
?>
<?php
global $config;
$ts_enabled = false;

foreach ($config['filter']['rule'] as $some_rule) {

    if (strpos(strtolower($some_rule['descr']), 'threatstop') !== false) {
        $ts_enabled = true;
    }

}

$uninstall_button = '';

if ($ts_enabled) {
    $ts_status = "Enabled";
    $tsactions = '<a href="tsdisable.php"><button>Disable</button></a>';
} else {
    $ts_status = "Disabled";
    $tsactions = '<a href="tsenable.php"><button>Enable</button></a><a href="tsremove.php"><button>Remove ThreatSTOP</button></a>';
}


$ts_errors = '';
if(file_exists("{$g['varrun_path']}/filter_reload_status"))
        $ts_errors = file_get_contents("{$g['varrun_path']}/filter_reload_status");

?>
<?php echo '
<style>
#tsstatus span {
  font-size: 24px;
  margin-right: 20px;
}
#tslogo {
  width: 180px;
  margin-bottom: 25px;
}
#loginlink {
  float: right;
  font-size: 20px;
  margin-right: 30px;
}
#tsactions {
}
#tsactions button {
  border-radius: 15px;
  font-size: 20px;
  margin-right: 15px;
  outline: none;
}
#tsactions button:hover {
  background-color: #bbb;
}
</style>
';
?>

<img src="/ts_logo_bw.png" id="tslogo" />
<span id="loginlink">
  Links
  <ul>
  <li><a target="threatstop" href="https://admin.threatstop.com/">ThreatSTOP Admin Portal login</a><br/></li>
  <li><a target="threatstopdocs" href="https://docs.threatstop.com/pfsense2.html">Documentation</a></li>
  </ul>
</span>


<div id="tsstatus">
  <span>Status:</span>
  <span><?= $ts_status ?></span>
  <span id="tsactions">
    <?= $tsactions ?>
  </span>
  <br/>
  <span>
  Device ID:
  </span>
  <span><?= $TDID ? $TDID: "Not Set" ?></span>
</div>

<?php echo $uninstall_button; ?>

<?php if ($ts_errors and $ts_enabled) {?>
<br />
<br />
<div style="font-size: 20px;"> Installation log </div>
<div id="status" name="status" style="padding:5px; border:1px dashed #990000; background-color: #ffffff; color: #000000;">
        <?php echo str_replace("\n", "<br/>\n", $ts_errors); ?>
</div>
<br />

</form><?php } ?>
<?php
  // Changed in 2.4
  if (file_exists("foot.inc")) {
        include("foot.inc");
  }
  // <= 2.3
  if (file_exists("fend.inc")) {
        include("fend.inc");
  }
?>
</body>
</html>
